@@ -142,6 +142,9 @@ def readSBMLnetwork_symbionts(filename, name) :
     model = get_model(sbml)
 
     listOfReactions = get_listOfReactions(model)
+    if listOfReactions is None:
+        logger.critical('No reaction in SBML '+filename)
+        sys.exit(1)
     for e in listOfReactions:
         if e.tag[0] == "{":
             uri, tag = e.tag[1:].split("}")
@@ -196,6 +199,9 @@ def readSBMLnetwork_symbionts_clyngor(filename, name) :
     model = get_model(sbml)
 
     listOfReactions = get_listOfReactions(model)
+    if listOfReactions is None:
+        logger.critical('No reaction in SBML '+filename)
+        sys.exit(1)
     for e in listOfReactions:
         if e.tag[0] == "{":
             uri, tag = e.tag[1:].split("}")
@@ -261,6 +267,9 @@ def readSBMLnetwork_symbionts_noemptyrctprd(filename, name) :
     model = get_model(sbml)
 
     listOfReactions = get_listOfReactions(model)
+    if listOfReactions is None:
+        logger.critical('No reaction in SBML '+filename)
+        sys.exit(1)
     for e in listOfReactions:
         if e.tag[0] == "{":
             uri, tag = e.tag[1:].split("}")
@@ -317,6 +326,9 @@ def readSBMLnetwork_em(filename, externalcomp="e") :
         quit()
 
     listOfReactions = get_listOfReactions(model)
+    if listOfReactions is None:
+        logger.critical('No reaction in SBML '+filename)
+        sys.exit(1)
     for e in listOfReactions:
         if e.tag[0] == "{":
             uri, tag = e.tag[1:].split("}")
@@ -386,6 +398,9 @@ def readSBMLnetwork_em_noemptyrctprd(filename, externalcomp="e") :
         quit()
 
     listOfReactions = get_listOfReactions(model)
+    if listOfReactions is None:
+        logger.critical('No reaction in SBML '+filename)
+        sys.exit(1)
     for e in listOfReactions:
         if e.tag[0] == "{":
             uri, tag = e.tag[1:].split("}")
